<?php
/**
 * Display affiliate banner widget for iStripper.
 *
 * @author 		Totem Entertainment
 * @category 	Widgets
 * @package 	iStripper Banners Widget/Widgets
 * @version 	1.2.0
 * @extends 	WP_Widget
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Widget - iStripper - Affiliate Banners
 */
class TotemTools_Affiliate_Banners extends WP_Widget {

	public $widget_cssclass;
	public $widget_description;
	public $widget_id;
	public $widget_name;
	public $settings;

	/**
	 * Constructor
	 */
	public function __construct() {
		$this->widget_cssclass 		= 'TotemTools WPBan';
		$this->widget_description 	= sprintf( __( 'Display a banner of your choice that links to your %s referral link.', 'totemtools-banners-widget' ), 'AffiliateWP' );
		$this->widget_id 			= 'totemtools_wp_banner_widget';
		$this->widget_name 			= 'iStripper ' . __( 'Affiliate Banner', 'totemtools-banners-widget' );

		$this->settings = array(
			'title' 			=> array(
				'type' 			=> 'text',
				'std' 			=> 'iStripper',
				'label' 		=> __( 'Title', 'totemtools-banners-widget' )
			),
			'affiliate_id' 	=> array(
				'type' 			=> 'text',
				'label' 		=> __( 'Affiliate ID', 'totemtools-banners-widget' )
			),
			'nude' 			=> array(
				'type' 			=> 'checkbox',
				'label' 		=> __( 'Including nude banner ?', 'totemtools-banners-widget' )
			),
			'size' 				=> array(
				'type' 			=> 'select',
				'options' 		=> array(
					'300x250'		=> '300x250',
					'160x600'		=> '160x600',
					'728x90'		=> '728x90',
					'250x250'		=> '250x250',
					'402x300'		=> '402x300',
					'336x768'		=> '336x768',
					'200x300'		=> '200x300',
					'190x262'		=> '190x262',
					'682x1024'		=> '682x1024',
					'604x300'		=> '604x300',
					'150x150'		=> '150x150',
				),
				'label' => __( 'Size', 'totemtools-banners-widget')
			),
			'lang' 				=> array(
				'type' 			=> 'select',
				'options' 		=> array(
					'auto'					=> 'Auto-detected',
					'fr' 					=> 'French', 
					'us' 					=> 'English', 
					'de' 					=> 'German',  
					'es'					=> 'Spanish',
					'ru' 					=> 'Russian', 
					'jp' 					=> 'Japanese', 
					'cn' 					=> 'Chinese', 
				
				),
				'label' => __( 'Language', 'totemtools-banners-widget')
			),
		);

		$widget_ops = array(
			'classname'   => $this->widget_cssclass,
			'description' => $this->widget_description
		);

		// Refreshing the widget's cached output with each new post
		add_action( 'save_post',    array( $this, 'flush_widget_cache' ) );
		add_action( 'deleted_post', array( $this, 'flush_widget_cache' ) );
		add_action( 'switch_theme', array( $this, 'flush_widget_cache' ) );

		parent::__construct(
			$this->widget_id, // Base ID
			$this->widget_name, // Name,
			$widget_ops // Args
		);
	}

	/**
	 * Return the widget slug.
	 *
	 * @return  Plugin slug variable.
	 */
	public function get_widget_slug() {
		return $this->widget_id;
	}

	/**
	 * Outputs the content of the widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @access public
	 *
	 * @param array $args 		Widgets arguments.
	 * @param array $instance 	Saved values from database.
	 */
	public function widget( $args, $instance ) {
		// Check if there is a cached output
		$cache = wp_cache_get( $this->get_widget_slug(), 'widget' );

		if( !is_array( $cache ) )
			$cache = array();

		if( !isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->get_widget_slug();

		if( isset( $cache[ $args['widget_id'] ] ) )
			return print $cache[ $args['widget_id'] ];

		ob_start();
		extract( $args, EXTR_SKIP );

		// these are the widget options
		$title         = $instance['title'];
		$affiliate_id  = $instance['affiliate_id'];
		$size          = $instance['size'];
		$nonude        = ( $instance['nude'] == 1  ) ? 0 : 1;
		$lang          = $instance['lang'];

		echo $args['before_widget'];

		// Display Ad
		if ( $size != '' ) {
			echo '<div class="widget-text istripper">';
			// if the title is set
			if ( $title ) {
				echo $args['before_title'] . $title . $args['after_title'];
			}
				
			
			$size_iframe = explode("x", $size);
			?>
			<a href="http://spklmis.com/?p=28&s=<?= $affiliate_id ?>" target="_blank" rel="follow" style="margin:0;padding:0;border:0;text-decoration:none;font-size:0">
				<img src="//misslk.com/s.php?w=<?= $size_iframe[0] ?>&h=<?= $size_iframe[1] ?>&m=0&i=0&l=<? $lang ?>&n=<?= $nonude ? 2 : 0 ?>" alt="hot girl striptease sexy nude poledance desktop stripper" height="<?= $size_iframe[1] ?>" width="<?= $size_iframe[0] ?>" style="border:0;position:relative;width:<?= $size_iframe[0] ?>px;height:auto">
			</a>
			<?php
			echo '</div>';
		}
		echo $args['after_widget'];

		$content = ob_get_clean();

		echo $content;

		$this->cache_widget( $args, $content );
	}

	/**
	 * Cache the widget
	 */
	public function cache_widget( $args, $content ) {
		$cache[ $args['widget_id'] ] = $content;

		wp_cache_set( $this->widget_id, $cache, 'widget' );
	}

	/**
	 * Flush the cache
	 * @return [type]
	 */
	public function flush_widget_cache() {
		wp_cache_delete( $this->get_widget_slug(), 'widget' );
	}

	/**
	 * Processes the widget's options to be saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array new_instance - The new instance of values to be generated via the update.
	 * @param array old_instance - The previous instance of values before the update.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] 			= ( !empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		
		$instance['affiliate_id'] 	= strip_tags( $new_instance['affiliate_id'] );
		$instance['size'] 			= strip_tags( $new_instance['size'] );
		$instance['nude'] 			= strip_tags( $new_instance['nude'] );
		$instance['lang'] 			= strip_tags( $new_instance['lang'] );

		$this->flush_widget_cache();

		return $instance;
	}

	/**
	 * Generates the administration form for the widget.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array instance The array of keys and values for the widget.
	 */
	public function form( $instance ) {
		$instance = wp_parse_args(
			(array) $instance
		);

		$title 			= esc_attr( $instance['title'] );
		
		$affiliate_id 	= esc_attr( $instance['affiliate_id'] );
		$size 			= esc_attr( $instance['size'] );
		$nude 			= esc_attr( $instance['nude'] );
		$lang 			= esc_attr( $instance['lang'] );

		if( ! $this->settings )
			return;

		foreach( $this->settings as $key => $setting ) {

			$value   = isset( $instance[ $key ] ) ? $instance[ $key ] : $setting['std'];

			switch ( $setting['type'] ) {
				case "text" :
					?>
					<p>
						<label for="<?php echo $this->get_field_id( $key ); ?>"><?php echo $setting['label']; ?></label>
						<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( $key ) ); ?>" name="<?php echo $this->get_field_name( $key ); ?>" type="text" value="<?php echo esc_attr( $value ); ?>" />
					</p>
					<?php
				break;
				case "number" :
					?>
					<p>
						<label for="<?php echo $this->get_field_id( $key ); ?>"><?php echo $setting['label']; ?></label>
						<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( $key ) ); ?>" name="<?php echo $this->get_field_name( $key ); ?>" type="number" step="<?php echo esc_attr( $setting['step'] ); ?>" min="<?php echo esc_attr( $setting['min'] ); ?>" max="<?php echo esc_attr( $setting['max'] ); ?>" value="<?php echo esc_attr( $value ); ?>" />
					</p>
					<?php
				break;
				case "select" :
					?>
					<p>
						<label for="<?php echo $this->get_field_id( $key ); ?>"><?php echo $setting['label']; ?></label>
						<select class="widefat" id="<?php echo esc_attr( $this->get_field_id( $key ) ); ?>" name="<?php echo $this->get_field_name( $key ); ?>">
							<?php foreach ( $setting['options'] as $option_key => $option_value ) : ?>
								<option value="<?php echo esc_attr( $option_key ); ?>" <?php selected( $option_key, $value ); ?>><?php echo esc_html( $option_value ); ?></option>
							<?php endforeach; ?>
						</select>
					</p>
					<?php
				break;
				case "checkbox" :
					?>
					<p>
						<input id="<?php echo esc_attr( $this->get_field_id( $key ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( $key ) ); ?>" type="checkbox" value="1" <?php checked( $value, 1 ); ?> />
						<label for="<?php echo $this->get_field_id( $key ); ?>"><?php echo $setting['label']; ?></label>
					</p>
					<?php
				break;
			}
		}
	}

}

register_widget('TotemTools_Affiliate_Banners');

?>